==> drd-8.x-3.0-rc2.tar.gz: drd/src/HttpRequest.php <==
<?php

namespace Drupal\drd;

use Drupal\drd\Entity\DomainInterface;
use GuzzleHttp\Client;
use Psr\Http\Message\ResponseInterface;

/**
 * Class HttpRequest.
 *
 * @package Drupal\drd
 */
class HttpRequest {

  public static function getVersion() {
    $modules = system_rebuild_module_data();
    $version = $modules['drd']->info['version'];
    return empty($version) ? '8.x-3.x' : $version;
  }

  /**
   * @var DomainInterface
   */
  protected $domain;

  /**
   * @var string
   */
  protected $query = '';

  /**
   * @var array
   */
  protected $options = [];

  /**
   * @var ResponseInterface
   */
  protected $response;

  /**
   * @var int
   */
  protected $statusCode;

  /**
   * @var bool
   */
  protected $remoteIsDrd;

  /**
   * @param DomainInterface $domain
   * @return $this
   */
  public function setDomain($domain) {
    $this->domain = $domain;
    return $this;
  }

  /**
   * @param string $query
   * @return $this
   */
  public function setQuery($query) {
    $this->query = $query;
    return $this;
  }

  /**
   * @param string $key
   * @param string $value
   * @return $this
   */
  public function setOption($key, $value) {
    $this->options[$key] = $value;
    return $this;
  }

  /**
   * @return string|bool
   * @throws \Exception
   */
  public function getResponse() {
    if (empty($this->response)) {
      // We haven't received anything from remote
      return FALSE;
    }
    if (!$this->isRemoteDrd()) {
      // We received something from remote, but not from DRD remote
      throw new \Exception('Remote domain does not respond as DRD.');
    }

    // Let's decode the response from DRD remote
    $body = base64_decode($this->response->getBody()->getContents());
    if ($body === FALSE) {
      // Reponse can not be decoded
      throw new \Exception('Received unexpected content.');
    }

    // Return the actual response
    return $body;
  }

  /**
   * @return int
   */
  public function getStatusCode() {
    return $this->statusCode;
  }

  /**
   * @return bool
   */
  public function isRemoteDrd() {
    return $this->remoteIsDrd;
  }

  /**
   * @return void
   */
  public function request() {
    $url = $this->domain->buildUrl($this->query);
    $this->options['headers'] = $this->domain->getHeader();
    $this->options['headers']['X-Drd-Version'] = self::getVersion();
    $this->statusCode = -1;
    $this->remoteIsDrd = FALSE;
    try {
      $client = new Client(['base_uri' => $url->toUriString()]);
      $this->response = $client->request('post', NULL, $this->options);
      $this->statusCode = $this->response->getStatusCode();
      $this->remoteIsDrd = ($this->statusCode == 200 && $this->response->getHeaderLine('content-type') == 'text/plain; charset=utf-8');
    }
    catch (\Exception $ex) {
      $this->statusCode = $ex->getCode();
    }
  }

}

==> drd-8.x-3.2.tar.gz: drd/src/HttpRequest.php <==
<?php

namespace Drupal\drd;

use Drupal\drd\Entity\DomainInterface;
use GuzzleHttp\Client;
use Psr\Http\Message\ResponseInterface;

/**
 * Class HttpRequest.
 *
 * @package Drupal\drd
 */
class HttpRequest {

  public static function getVersion() {
    return LibraryBuild::DRD_LIBRARY_VERSION;
  }

  /**
   * @var DomainInterface
   */
  protected $domain;

  /**
   * @var string
   */
  protected $query = '';

  /**
   * @var array
   */
  protected $options = [];

  /**
   * @var ResponseInterface
   */
  protected $response;

  /**
   * @var int
   */
  protected $statusCode;

  /**
   * @var bool
   */
  protected $remoteIsDrd;

  /**
   * @param DomainInterface $domain
   * @return $this
   */
  public function setDomain($domain) {
    $this->domain = $domain;
    return $this;
  }

  /**
   * @param string $query
   * @return $this
   */
  public function setQuery($query) {
    $this->query = $query;
    return $this;
  }

  /**
   * @param string $key
   * @param string $value
   * @return $this
   */
  public function setOption($key, $value) {
    $this->options[$key] = $value;
    return $this;
  }

  /**
   * @return string|bool
   * @throws \Exception
   */
  public function getResponse() {
    if (empty($this->response)) {
      // We haven't received anything from remote
      return FALSE;
    }
    if (!$this->isRemoteDrd()) {
      // We received something from remote, but not from DRD remote
      throw new \Exception('Remote domain does not respond as DRD.');
    }

    // Let's decode the response from DRD remote
    $body = base64_decode($this->response->getBody()->getContents());
    if ($body === FALSE) {
      // Reponse can not be decoded
      throw new \Exception('Received unexpected content.');
    }

    // Return the actual response
    return $body;
  }

  /**
   * @return int
   */
  public function getStatusCode() {
    return $this->statusCode;
  }

  /**
   * @return bool
   */
  public function isRemoteDrd() {
    return $this->remoteIsDrd;
  }

  /**
   * @return void
   */
  public function request() {
    $url = $this->domain->buildUrl($this->query);
    $this->options['headers'] = $this->domain->getHeader();
    $this->options['headers']['X-Drd-Version'] = self::getVersion();
    $this->statusCode = -1;
    $this->remoteIsDrd = FALSE;
    try {
      $client = new Client(['base_uri' => $url->toUriString()]);
      $this->response = $client->request('post', NULL, $this->options);
      $this->statusCode = $this->response->getStatusCode();
      $this->remoteIsDrd = (
        $this->statusCode == 200 &&
        $this->response->getHeaderLine('content-type') == 'text/plain; charset=utf-8' &&
        $this->response->getHeaderLine('x-drd-agent') == 'self::getVersion()'
      );
    }
    catch (\Exception $ex) {
      $this->statusCode = $ex->getCode();
    }
  }

}
